var structpw__protocol__client =
[
    [ "connect", "structpw__protocol__client.html#a9ad81c815efd4cb103082c04dc81c2c6", null ],
    [ "connect_fd", "structpw__protocol__client.html#a3a1eab74dcd34901463bbc3cc2232b7b", null ],
    [ "destroy", "structpw__protocol__client.html#a9ce571a5bc950b3309d0dbd2a55e501f", null ],
    [ "disconnect", "structpw__protocol__client.html#a4b60903a56e79e980b11ea2d14fac80c", null ],
    [ "link", "structpw__protocol__client.html#addd42578b59ddffc32a42a52754654be", null ],
    [ "protocol", "structpw__protocol__client.html#a2f6233dcd7a026275a93680ae68ee263", null ],
    [ "remote", "structpw__protocol__client.html#a6879f664fbafbd1279e7f3cce224a25a", null ],
    [ "steal_fd", "structpw__protocol__client.html#ae94059a4fa05da14961edb56be183f2a", null ]
];